mailr8360 - /branches/relax_disp/specific_fns/relax_disp.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by sebastien . morin . 1 on January 10, 2009 - 17:48:
Author: semor
Date: Sat Jan 10 17:48:17 2009
New Revision: 8360

URL: http://svn.gna.org/viewcvs/relax?rev=8360&view=rev
Log:
Corrected a few dosctrings.


Modified:
    branches/relax_disp/specific_fns/relax_disp.py

Modified: branches/relax_disp/specific_fns/relax_disp.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/relax_disp/specific_fns/relax_disp.py?rev=8360&r1=8359&r2=8360&view=diff
==============================================================================
--- branches/relax_disp/specific_fns/relax_disp.py (original)
+++ branches/relax_disp/specific_fns/relax_disp.py Sat Jan 10 17:48:17 2009
@@ -43,10 +43,10 @@
 
 
 class Relax_disp(Common_functions):
     """Class containing functions for relaxation curve fitting."""
 
     def assemble_param_vector(self, spin=None, sim_index=None):
-        """Assemble the dispersion relaxation curve-fitting parameter vector 
(as a numpy array).
+        """Assemble the dispersion relaxation dispersion curve-fitting 
parameter vector (as a numpy array).
 
         @keyword spin:          The spin data container.
         @type spin:             SpinContainer instance
@@ -410,8 +410,8 @@
 
     def default_value(self, param):
         """
-        Relaxation curve fitting default values
-        ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+        Relaxation dispersion curve fitting default values
+        ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
         These values are arbitrary and will depend on the system studied.
         
________________________________________________________________________________
@@ -550,7 +550,7 @@
 
 
     def grid_search(self, lower=None, upper=None, inc=None, 
constraints=True, verbosity=1, sim_index=None):
         """The exponential curve fitting grid search function.
 
         @keyword lower:         The lower bounds of the grid search which 
must be equal to the
                                 number of parameters in the model.
@@ -684,7 +684,7 @@
 
 
     def linear_constraints(self, spin=None, scaling_matrix=None):
-        """Set up the relaxation curve fitting linear constraint matrices A 
and b.
+        """Set up the relaxation dispersion curve fitting linear constraint 
matrices A and b.
 
         Standard notation
         =================
@@ -755,7 +755,7 @@
 
 
     def minimise(self, min_algor=None, min_options=None, func_tol=None, 
grad_tol=None, max_iterations=None, constraints=False, scaling=True, 
verbosity=0, sim_index=None, lower=None, upper=None, inc=None):
         """Relaxation curve fitting function.
 
         @keyword min_algor:         The minimisation algorithm to use.
         @type min_algor:            str
@@ -943,7 +943,7 @@
     def model_setup(self, model, params):
         """Update various model specific data structures.
 
-        @param model:   The exponential curve type.
+        @param model:   The relaxation dispersion curve type.
         @type model:    str
         @param params:  A list consisting of the model parameters.
         @type params:   list of str
@@ -1023,8 +1023,8 @@
 
     def return_data_name(self, name):
         """
-        Relaxation curve fitting data type string matching patterns
-        ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+        Relaxation dispersion curve fitting data type string matching 
patterns
+        
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
         
_________________________________________________________________________________________________
         |                                                   |                
|                          |
@@ -1132,7 +1132,7 @@
 
 
     def select_model(self, model='fast'):
         """Function for selecting the model of the exponential curve.
curve.
 
         @keyword model: The relaxation dispersion time scale for curve 
@@ -43,10 +43,10 @@
 
 class Relax_disp(Common_functions):
-    """Class containing functions for relaxation curve fitting."""
+    """Class containing functions for relaxation dispersion curve fitting."""
 
     def assemble_param_vector(self, spin=None, sim_index=None):
@@ -550,7 +550,7 @@
     def grid_search(self, lower=None, upper=None, inc=None, 
constraints=True, verbosity=1, sim_index=None):
-        """The exponential curve fitting grid search function.
+        """The relaxation dispersion curve fitting grid search function.
 
         @keyword lower:         The lower bounds of the grid search which 
@@ -755,7 +755,7 @@
grad_tol=None, max_iterations=None, constraints=False, scaling=True, 
verbosity=0, sim_index=None, lower=None, upper=None, inc=None):
-        """Relaxation curve fitting function.
+        """Relaxation dispersion curve fitting function.
 
         @keyword min_algor:         The minimisation algorithm to use.
@@ -1132,7 +1132,7 @@
 
     def select_model(self, model='fast'):
-        """Function for selecting the model of the exponential curve.
+        """Function for selecting the model of the relaxation dispersion 
curve.
 
fitting.  Can be one of
                         'fast' or 'slow'.




Related Messages


Powered by MHonArc, Updated Sat Jan 10 18:00:03 2009